model object, rank the input predictors (and combinations thereof)
by thier influence on the outputIf method is 'add' then the baseline prediction is made using just the
constant coefficients (if used) and the mean squared error (MSE) is measured between
the baseline and predictions made with each predictor added alone (univariate analysis).
get_influence(m, d, method = "sub", interactions = TRUE)Tucker_model or CP_model object
input_data object
string 'sub' or 'add' indicating whether to start with a full or empty feature vector and remove or add features to judge their influence.
logical indicating whether to get influence for two-way interactions between predictors (def: sub)
If method is 'sub' then the baseline is made using all predictors and
MSE measured for predictions made with each predictor removed.
If interactions==TRUE then MSE for predictions made with predictors for each mode
interacting are measured